package Wizard::LDAP::Config;
$Wizard::LDAP::Config::config = {
  'ldap-prefs-file' => '/etc/Wizard-LDAP/prefs'
};
